@@ -164,6 +164,10 @@ bacon_video_widget_properties_reset (BaconVideoWidgetProperties *props)
 			_("N/A"));
 	/* Audio Codec */
 	bacon_video_widget_properties_set_label (props, "acodec", _("N/A"));
+	/* Sample rate */
+	bacon_video_widget_properties_set_label (props, "samplerate", _("0 Hz"));
+	/* Channels */
+	bacon_video_widget_properties_set_label (props, "channels", _("0 Channels"));
 }
 
 void
@@ -246,6 +250,9 @@ bacon_video_widget_properties_update (BaconVideoWidgetProperties *props,
 		UPDATE_FROM_INT (BVW_INFO_AUDIO_BITRATE, "audio_bitrate",
 				 N_("%d kbps"), _("N/A"));
 		UPDATE_FROM_STRING (BVW_INFO_AUDIO_CODEC, "acodec");
+		UPDATE_FROM_INT (BVW_INFO_AUDIO_SAMPLE_RATE, "samplerate",
+				N_("%d Hz"), _("N/A"));
+		UPDATE_FROM_STRING (BVW_INFO_AUDIO_CHANNELS, "channels");
 	}
 
 #undef UPDATE_FROM_STRING
@@ -276,6 +283,12 @@ bacon_video_widget_properties_new (void)
 	BaconVideoWidgetProperties *props;
 	GladeXML *xml;
 	GtkWidget *vbox;
+	GtkSizeGroup *group;
+	const char *labels[] = { "title_label", "artist_label", "album_label",
+			"year_label", "duration_label", "dimensions_label", "vcodec_label",
+			"framerate_label", "vbitrate_label", "abitrate_label",
+			"acodec_label", "samplerate_label", "channels_label" };
+	guint i;
 
 	xml = totem_interface_load_with_root ("properties.glade",
 			"vbox1", _("Properties dialog"), TRUE, NULL);
@@ -292,6 +305,14 @@ bacon_video_widget_properties_new (void)
 
 	bacon_video_widget_properties_reset (props);
 
+	group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
+
+	for (i = 0; i < G_N_ELEMENTS (labels); i++)
+		gtk_size_group_add_widget (group, glade_xml_get_widget (xml,
+				labels[i]));
+
+	g_object_unref (group);
+
 	gtk_widget_show_all (GTK_WIDGET (props));
 
 	return GTK_WIDGET (props);
