@@ -638,7 +638,9 @@ totem_recent_manager_changed_callback (GtkRecentManager *recent_manager, Totem *
 void
 totem_setup_recent (Totem *totem)
 {
-	totem->recent_manager = gtk_recent_manager_get_default ();
+	GdkScreen *screen;
+	screen = gtk_widget_get_screen (totem->win);
+	totem->recent_manager = gtk_recent_manager_get_for_screen (screen);
 	totem->recent_action_group = NULL;
 	totem->recent_ui_id = gtk_ui_manager_new_merge_id
 			(totem->ui_manager);
@@ -657,11 +659,11 @@ totem_action_add_recent (Totem *totem, const char *filename)
 	char *groups[] = { NULL, NULL };
 
 	data.mime_type = gnome_vfs_get_mime_type (filename);
+	data.display_name = NULL;
 
 	if (strstr (filename, "file:///") == NULL) {
 		/* It's a URI/stream */
 		groups[0] = "TotemStreams";
-		data.display_name = NULL;
 	} else {
 		char *display;
 
@@ -1079,6 +1081,7 @@ about_action_callback (GtkAction *action, Totem *totem)
 		"Bastien Nocera <hadess@hadess.net>",
 		"Ronald Bultje <rbultje@ronald.bitfreak.net>",
 		"Julien Moutte <julien@moutte.net> (GStreamer backend)",
+		"Tim-Philipp M\303\274ller <tim\100centricular\056net> (GStreamer backend)",
 		NULL
 	};
 	const char *artists[] = { "Jakub Steiner <jimmac@ximian.com>", NULL };
