@@ -420,6 +420,19 @@ totem_scrsaver_enable (TotemScrsaver *scr)
 #endif
 }
 
+void
+totem_scrsaver_set_state (TotemScrsaver *scr, gboolean enable)
+{
+	if (scr->priv->disabled == !enable)
+		return;
+
+	scr->priv->disabled = !enable;
+	if (scr->priv->disabled != FALSE)
+		totem_scrsaver_disable (scr);
+	else
+		totem_scrsaver_enable (scr);
+}
+
 static void
 totem_scrsaver_finalize (GObject *object)
 {
