@@ -788,12 +788,15 @@ totem_action_open_location (Totem *totem)
 
 		for (p = recent_items; p != NULL; p = p->next)
 		{
-			if (!gtk_recent_info_has_group ((GtkRecentInfo *) p->data, "TotemStreams"))
+			GtkRecentInfo *info = (GtkRecentInfo *) p->data;
+			if (!gtk_recent_info_has_group (info, "TotemStreams")) {
+				gtk_recent_info_unref (info);
 				continue;
+			}
 
 			gtk_list_store_append (GTK_LIST_STORE (model), &iter);
-			gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, gtk_recent_info_get_uri ((GtkRecentInfo *) p->data), -1);
-			gtk_recent_info_unref ((GtkRecentInfo *) p->data);
+			gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, gtk_recent_info_get_uri (info), -1);
+			gtk_recent_info_unref (info);
 		}
 	}
 
@@ -2626,7 +2629,6 @@ totem_action_handle_key_press (Totem *totem, GdkEventKey *event)
 		break;
 #ifdef HAVE_XFREE
 	case XF86XK_AudioPlay:
-	case XF86XK_AudioPause:
 #endif /* HAVE_XFREE */
 	case GDK_p:
 	case GDK_P:
@@ -2635,6 +2637,12 @@ totem_action_handle_key_press (Totem *totem, GdkEventKey *event)
 		else 
 			totem_action_play_pause (totem);
 		break;
+#ifdef HAVE_XFREE
+	case XF86XK_AudioPause:
+	case XF86XK_AudioStop:
+		totem_action_pause (totem);
+		break;
+#endif /* HAVE_XFREE */
 	case GDK_q:
 	case GDK_Q:
 		totem_action_exit (totem);
@@ -3036,6 +3044,7 @@ totem_setup_window (Totem *totem)
 	g_signal_connect (G_OBJECT (main_pane), "size-allocate", G_CALLBACK (main_pane_size_allocated), totem);
 
 	totem_sidebar_setup (totem, show_sidebar, page_id);
+        g_free (page_id);
 }
 
 static void
@@ -3207,6 +3216,9 @@ totem_callback_connect (Totem *totem)
 	totem_action_set_sensitivity ("play", FALSE);
 	totem_action_set_sensitivity ("next-chapter", FALSE);
 	totem_action_set_sensitivity ("previous-chapter", FALSE);
+	totem_action_set_sensitivity ("skip-forward", FALSE);
+	totem_action_set_sensitivity ("skip-backwards", FALSE);
+	totem_action_set_sensitivity ("skip-to", FALSE);
 
 #ifdef HAVE_MEDIA_PLAYER_KEYS
 	g_signal_connect (G_OBJECT(totem->win), "focus-in-event",
